==> minitube_0.9.orig.tar.gz: minitube/locale/he_IL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>יש חיים מחוץ לדפדפן!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>גרסה %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>זוהי הצגה טכנולוגית מקדימה, אל תצפו ממנה להיות מושלמת.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>יש לדווח על באגים ורעיונות אל %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 הינה תוכנה חופשית אך פיתוחה לוקח המון זמן יקר.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>אנא &lt;a href=&apos;%1&apos;&gt;תרמו באמצעות PayPal&lt;/a&gt; כדי לתמוך בהמשך הפיתוח של %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>הסמל עוצב על ידי %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>המצב החסכוני נתרם על ידי %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>תורגם על ידי %1.</translation>
    </message>
    <message>
        <source>Released under the </source>
        <translation>שוחרר תחת תנאי</translation>
    </message>
    <message>
        <source></source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <source>About</source>
        <translation>על אודות</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>מה שתמיד רצית לדעת אודות %1 ולא העזת לשאול</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>התוכנה שוחררה תחת תנאי &lt;a href=&apos;%1&apos;&gt;הרישיון הציבורי הכללי של GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>התמיכה במתווך HTTP נתרמה על ידי %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation>הגרסה ל־Windows נבנתה על ידי %1</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>מחיקה</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>מחפש...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>הצגת %1 נוספים</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>אין סרטונים</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>אין עוד סרטונים</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source></source>
        <translation>&amp;חזרה</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>מעבר אל התצוגה הקודמת</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;עצירה</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>עצירת הנגינה וחזרה אל תצוגת החיפוש</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;דילוג</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>דילוג אל הסרטון הבא</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>ה&amp;שהיה</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>השהיית הנגינה</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;מסך מלא</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>מעבר למסך מלא</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>מצב &amp;חסכוני</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>הסתרת רשימת ההשמעה וסרגל הכלים</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>פתיחת עמוד הווידאו ב־YouTube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>ה&amp;סרה</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>הסרת הסרטונים הנבחרים מרשימת ההשמעה</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>הזזה מ&amp;מעלה</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>הזזת הסרטונים הנבחרים במעלה רשימת ההשמעה</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>הזזה מ&amp;טה</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>הזזת הסרטונים הנבחרים במורד רשימת ההשמעה</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>להתראות</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;אתר האינטרנט</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 באינטרנט</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>&amp;תרומה באמצעות PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>אנא תמכו בהמשך הפיתוח של %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;על אודות</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>מידע אודות %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;חיפוש</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;יישום</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;רשימת השמעה</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;וידאו</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 נפתח</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>שגיאה מכרעת: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>שגיאה: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;נגינה</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>המשך הנגינה</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>יציאה ממ&amp;סך מלא</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;חזרה</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>השתקת השמע</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>ניתן ללחוץ על %1 כדי להגביר את עצמת השמע, %2 כדי להנמיך אותה</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>הזמן הנותר: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>עצמת השמע היא %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>השמע מושתק</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>השמע אינו מושתק</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>האפשרות לצפיה באיכות גבוהה פעילה</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>האפשרות לצפיה באיכות גבוהה אינה פעילה</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>סרטון הווידאו הנוכחי הינו באיכות גבוהה (HD)</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>סרטון הווידאו הנוכחי אינו באיכות גבוהה (HD)</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>מחיקת &amp;מילות המפתח האחרונות</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>הרלוונטיים ביותר</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>העדכניים ביותר</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>הנצפים ביותר</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>הנכם צופים ב־&quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>שגיאת רשת: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 צפיות</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>ברוכים הבאים אל &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>הזינו מילת מפתח כדי להתחיל לצפות בסרטונים.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>צפיה</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>מילות מפתח אחרונות</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>גרסה חדשה של %1 זמינה להורדה. אנא &lt;a href=&apos;%2&apos;&gt;עדכנו לגרסה %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>שבו בניחותא</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>העדפות</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>שגיאת רשת: %1 עבור %2</translation>
    </message>
</context>
</TS>

==> minitube_1.1.orig.tar.gz: minitube/locale/he_IL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>יש חיים מחוץ לדפדפן!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>גרסה %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">הפצה זו הנה &quot;הצגה טכנולוגית מקדימה&quot;, אל תצפו ממנה להיות מושלמת.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>יש לדווח על באגים ורעיונות אל %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 הינה תוכנה חופשית אך פיתוחה לוקח המון זמן יקר.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">אנא &lt;a href=&apos;%1&apos;&gt;תרמו באמצעות PayPal&lt;/a&gt; כדי לתמוך בהמשך הפיתוח של %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>הסמל עוצב על ידי %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>המצב החסכוני נתרם על ידי %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>תורגם על ידי %1.</translation>
    </message>
    <message>
        <source>Released under the </source>
        <translation type="obsolete">שוחרר תחת תנאי</translation>
    </message>
    <message>
        <source></source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <source>About</source>
        <translation>על אודות</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>מה שתמיד רצית לדעת אודות %1 ולא העזת לשאול</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>התוכנה שוחררה תחת תנאי &lt;a href=&apos;%1&apos;&gt;הרישיון הציבורי הכללי של GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>התמיכה במתווך HTTP נתרמה על ידי %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">הגרסה ל־Windows נבנתה על ידי %1</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>אנא &lt;a href=&apos;%1&apos;&gt;תרמו&lt;/a&gt; כדי לתמוך בהמשך הפיתוח של %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>מחיקה</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>מחפש...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>הצגת %1 נוספים</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>אין סרטונים</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>אין עוד סרטונים</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source></source>
        <translation>&amp;חזרה</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">מעבר אל התצוגה הקודמת</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;עצירה</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>עצירת הנגינה וחזרה אל תצוגת החיפוש</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;דילוג</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>דילוג אל הסרטון הבא</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>ה&amp;שהיה</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>השהיית הנגינה</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;מסך מלא</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>מעבר למסך מלא</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>מצב &amp;חסכוני</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>הסתרת רשימת ההשמעה וסרגל הכלים</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">פתיחת עמוד הווידאו ב־YouTube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>ה&amp;סרה</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>הסרת הסרטונים הנבחרים מרשימת ההשמעה</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>הזזה מ&amp;מעלה</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>הזזת הסרטונים הנבחרים במעלה רשימת ההשמעה</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>הזזה מ&amp;טה</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>הזזת הסרטונים הנבחרים במורד רשימת ההשמעה</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>להתראות</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;אתר האינטרנט</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 באינטרנט</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;תרומה באמצעות PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>אנא תמכו בהמשך הפיתוח של %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;על אודות</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>מידע אודות %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;חיפוש</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;יישום</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;רשימת השמעה</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;וידאו</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 נפתח</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>שגיאה מכרעת: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>שגיאה: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;נגינה</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>המשך הנגינה</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>יציאה ממ&amp;סך מלא</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;חזרה</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>השתקת השמע</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>ניתן ללחוץ על %1 כדי להגביר את עצמת השמע, %2 כדי להנמיך אותה</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>הזמן הנותר: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>עצמת השמע היא %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>השמע מושתק</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>השמע אינו מושתק</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">האפשרות לצפיה באיכות גבוהה פעילה</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">האפשרות לצפיה באיכות גבוהה אינה פעילה</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">סרטון הווידאו הנוכחי הנו באיכות גבוהה (HD)</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">סרטון הווידאו הנוכחי אינו באיכות גבוהה (HD)</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>מחיקת &amp;מילות המפתח האחרונות</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>מחיקת היסטוריית החיפוש. לא ניתן לבטל</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>פרטיותך מוגנת כעת.</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>פthe &amp;תיחת העמוד ב־YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>מעבר לעמוד הווידאו ב־YouTube והשהיית הנגינה.</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>העתקת ה&amp;קישור ל־YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>העתקת הקישור אל הווידאו הנוכחי אל לוח הגזירים</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>העתקת כתובת &amp;תזרים הווידאו</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>העתקת כתובת תזרים הווידאו אל לוח הגזירים</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>&amp;מתן תרומה</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>איכות הנגינה המירבית מוגדרת ל־%1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>הרלוונטיים ביותר</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>העדכניים ביותר</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>הנצפים ביותר</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>הנכם צופים ב־&quot;%1&quot;</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>כעת ניתן להדביק את קישור ה־YouTube שלכם ליישום אחר</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>כעת ניתן להדביק את כתובת תזרים הווידאו ליישום אחר</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>הקישור יהיה תקף לזמן מוגבל בלבד.</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>שגיאת רשת: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 צפיות</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>ברוכים הבאים אל &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>הזינו מילת מפתח כדי להתחיל לצפות בסרטונים.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>צפיה</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>מילות מפתח אחרונות</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>גרסה חדשה של %1 זמינה להורדה. אנא &lt;a href=&apos;%2&apos;&gt;עדכנו לגרסה %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>שבו בניחותא</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">העדפות</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>שגיאת רשת: %1 עבור %2</translation>
    </message>
</context>
</TS>
